package cn.com.infosec.asn1.cms;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;

public class PasswordRecipientInfo extends ASN1Encodable {
   private DERInteger version;
   private AlgorithmIdentifier keyDerivationAlgorithm;
   private AlgorithmIdentifier keyEncryptionAlgorithm;
   private ASN1OctetString encryptedKey;

   public PasswordRecipientInfo(AlgorithmIdentifier keyEncryptionAlgorithm, ASN1OctetString encryptedKey) {
      PasswordRecipientInfo var10000 = this;
      PasswordRecipientInfo var10001 = this;
      PasswordRecipientInfo var10002 = this;
      super();
      DERInteger var3;
      var3 = new DERInteger.<init>(0);
      var10002.version = var3;
      var10001.keyEncryptionAlgorithm = keyEncryptionAlgorithm;
      var10000.encryptedKey = encryptedKey;
   }

   public PasswordRecipientInfo(AlgorithmIdentifier keyDerivationAlgorithm, AlgorithmIdentifier keyEncryptionAlgorithm, ASN1OctetString encryptedKey) {
      PasswordRecipientInfo var10000 = this;
      PasswordRecipientInfo var10001 = this;
      PasswordRecipientInfo var10002 = this;
      PasswordRecipientInfo var10003 = this;
      super();
      DERInteger var4;
      var4 = new DERInteger.<init>(0);
      var10003.version = var4;
      var10002.keyDerivationAlgorithm = keyDerivationAlgorithm;
      var10001.keyEncryptionAlgorithm = keyEncryptionAlgorithm;
      var10000.encryptedKey = encryptedKey;
   }

   public PasswordRecipientInfo(ASN1Sequence seq) {
      this.version = (DERInteger)seq.getObjectAt(0);
      if (seq.getObjectAt(1) instanceof ASN1TaggedObject) {
         this.keyDerivationAlgorithm = AlgorithmIdentifier.getInstance((ASN1TaggedObject)seq.getObjectAt(1), false);
         this.keyEncryptionAlgorithm = AlgorithmIdentifier.getInstance(seq.getObjectAt(2));
         this.encryptedKey = (ASN1OctetString)seq.getObjectAt(3);
      } else {
         this.keyEncryptionAlgorithm = AlgorithmIdentifier.getInstance(seq.getObjectAt(1));
         this.encryptedKey = (ASN1OctetString)seq.getObjectAt(2);
      }

   }

   public static PasswordRecipientInfo getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static PasswordRecipientInfo getInstance(Object obj) {
      if (obj != null && !(obj instanceof PasswordRecipientInfo)) {
         if (obj instanceof ASN1Sequence) {
            return new PasswordRecipientInfo((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("Invalid PasswordRecipientInfo: " + obj.getClass().getName());
         }
      } else {
         return (PasswordRecipientInfo)obj;
      }
   }

   public DERInteger getVersion() {
      return this.version;
   }

   public AlgorithmIdentifier getKeyDerivationAlgorithm() {
      return this.keyDerivationAlgorithm;
   }

   public AlgorithmIdentifier getKeyEncryptionAlgorithm() {
      return this.keyEncryptionAlgorithm;
   }

   public ASN1OctetString getEncryptedKey() {
      return this.encryptedKey;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var10001.add(this.version);
      AlgorithmIdentifier var2;
      if ((var2 = this.keyDerivationAlgorithm) != null) {
         DERTaggedObject var3;
         var3 = new DERTaggedObject.<init>(false, 0, var2);
         var1.add(var3);
      }

      var1.add(this.keyEncryptionAlgorithm);
      var1.add(this.encryptedKey);
      return new DERSequence(var1);
   }
}
